searchNodes=[{"ref":"Archivist.html","title":"Archivist","type":"module","doc":""},{"ref":"Archivist.Archive.html","title":"Archivist.Archive","type":"module","doc":"Module that coordinates the structured parsing and return of assets in the articles root directory. Precompiles and provides interface to interact with your articles. By most Elixir and Erlang conventions this module should be called &#39;Archivist.Repo&#39; since it&#39;s being used for data access, but this library is called Archivist so we&#39;re calling it an Archive. Deal with it. defmodule MyApp.Archive do use Archivist.Archive, root: &quot;some/other/dir&quot;, body_parser: Earmark end alias MyApp.Archive {:ok, articles} = Archive.all() {:ok, authors} = Archive.authors() {:ok, image_paths} = Archive.image_paths() {:ok, tags} = Archive.tags() {:ok, topics} = Archive.topics() {:ok, titles} = Archive.titles() {:ok, slugs} = Archive.slugs() {:ok, created_asc} = Archive.sort_by :created_at, :asc {:ok, published_desc} = Archive.sort_by :published_at, :desc {:ok, article} = Archive.fetch_by :slug, &quot;some-article&quot;"},{"ref":"Archivist.Article.html","title":"Archivist.Article","type":"module","doc":"The core datatype for Archivist. Articles are broken into header and body/content parts then compiled into the %Archivist.Article{} struct."},{"ref":"Archivist.Article.html#t:t/0","title":"Archivist.Article.t/0","type":"type","doc":""},{"ref":"Archivist.ArticleParser.html","title":"Archivist.ArticleParser","type":"module","doc":""},{"ref":"Archivist.ArticleParser.html#build_paths/4","title":"Archivist.ArticleParser.build_paths/4","type":"function","doc":""},{"ref":"Archivist.ArticleParser.html#convert_structs/2","title":"Archivist.ArticleParser.convert_structs/2","type":"function","doc":""},{"ref":"Archivist.ArticleParser.html#filter_valid/1","title":"Archivist.ArticleParser.filter_valid/1","type":"function","doc":""},{"ref":"Archivist.ArticleParser.html#parse_attr/2","title":"Archivist.ArticleParser.parse_attr/2","type":"function","doc":""},{"ref":"Archivist.ArticleParser.html#parse_attrs/2","title":"Archivist.ArticleParser.parse_attrs/2","type":"function","doc":""},{"ref":"Archivist.ArticleParser.html#parse_files/2","title":"Archivist.ArticleParser.parse_files/2","type":"function","doc":""},{"ref":"Archivist.ArticleParser.html#parse_topics/1","title":"Archivist.ArticleParser.parse_topics/1","type":"function","doc":""},{"ref":"Archivist.MapUtils.html","title":"Archivist.MapUtils","type":"module","doc":""},{"ref":"Archivist.MapUtils.html#deep_merge/2","title":"Archivist.MapUtils.deep_merge/2","type":"function","doc":""},{"ref":"readme.html","title":"Archivist","type":"extras","doc":"Archivist Archivist is a straightforward blogging utility for generating article content at compile time from version-controlled markdown files. It is built to be used in conjunction with the Arcdown plaintext article parser library. Archivist is inspired by the general approach of Cẩm Huỳnh&#39;s great Nabo library with some key differences: Archivist articles are formatted in Arcdown format by default, allowing for more robust articles and article features. Archivist is an opinionated piece of software, meaning it makes decisions about how your articles should be structured (Arcdown), how your content should be formatted (Markdown). Archivist allows articles to be organized into nested topic directories for better organization. Topic directories do not currently hold any semantic meaning, but in the future may be used to optionally infer topic assignment for articles within those directories. Archivist doesn&#39;t bother parsing your article summary as markdown because it&#39;s usually only a sentence or two, and you can do that on your own. Archivist adds default attributes for author names and email addresses, as well as sorting content by author. Archivist exposes its article sorting mechanism as an anonymous function, allowing users to implement custom article-sorting strategies at compile-time. Archivist allows you to set a created_at and published_at timestamps to give you greater control over content and how it&#39;s used. Archivist allows you to tag your articles however you&#39;d like. Archivist generates lists of tags, topics, and authors at compile-time, giving you more flexibility in your content&#39;s front-end presentation without having to perform additional parsing at runtime."},{"ref":"readme.html#installation","title":"Archivist - Installation","type":"extras","doc":"The package can be installed by adding archivist to your list of dependencies in mix.exs: def deps do [ {:archivist, &quot;~&gt; 0.2&quot;} ] end"},{"ref":"readme.html#usage","title":"Archivist - Usage","type":"extras","doc":"The heart of Archivist is the Archive module, which acts as a repository for exposing query functions for articles, slugs, topics, etc. You can create an Archive out of any Elixir module by using Archivist.Archive like this: defmodule MyApp.Archive use Archivist.Archive end # the alias is just a nicety here and isn&#39;t required by any means alias MyApp.Archive Archive.articles() Archive.topics() Archive.tags() Archive.slugs() Archive.authors() Archivist version 0.2.x expects you to create your article content directory at priv/archive/articles at the root of your elixir library, like this: priv/archive/articles/journey_to_the_center_of_the_earth.ad If you&#39;d like to customize any of your archive&#39;s behavior, you can define any of the following options when it is used in the target archive directory. The values shown are the defaults: defmodule MyApp.Archive use Archivist.Archive archive_dir: &quot;priv/archive&quot;, content_dir: &quot;articles&quot;, content_pattern: &quot;**/*.ad&quot;, image_dir: &quot;images&quot;, image_pattern: &quot;**/*.{jpg,gif,png}&quot;, article_sorter: &amp;(Map.get(&amp;1, :published_at) &gt;= Map.get(&amp;2, :published_at)) end Archivist will read any files with the .ad extension in your content directory or in any of its subdirectories, and parse the content of those files with the parser you&#39;ve selected (Arcdown by default) If you&#39;d like to store your archive somewhere besides priv/archive you can assign a custom path to your archive like this: defmodule MyApp.Archive use Archivist.Archive, archive_dir: &quot;assets/images&quot;, end Usage notes for Version 0.1.x Archivist version 0.1.x expects you to create your article content directory at priv/articles at the root of your elixir library, like this: priv/articles/journey_to_the_center_of_the_earth.ad The following options are availble in Version 0.1.x. Values shown are defaults: defmodule MyApp.Archive use Archivist.Archive content_dir: &quot;priv/articles&quot;, content_pattern: &quot;**/*.ad&quot;, image_dir: &quot;priv/images&quot;, image_pattern: &quot;**/*.{jpg,gif,png}&quot;, article_sorter: &amp;(Map.get(&amp;1, :published_at) &gt;= Map.get(&amp;2, :published_at))"},{"ref":"readme.html#arcdown","title":"Archivist - Arcdown","type":"extras","doc":"Arcdown supports the following features for articles: Article Content Article Summary Topics Sub-Topics Tags Published Datetime Creation Datetime Author Name Author Email Article Slug Here is an example article written in Arcdown (.ad) format: The Day the Earth Stood Still &lt;the-day-the-earth-stood-still&gt; by Julian Blaustein &lt;julian@blaustein.com&gt; Filed under: Films &gt; Sci-Fi &gt; Classic Created @ 10:24pm on 1/20/2019 Published @ 10:20pm on 1/20/2019 * Sci-Fi * Horror * Thrillers * Aliens Summary: A sci-fi classic about a flying saucer landing in Washington, D.C. --- The Day the Earth Stood Still (a.k.a. Farewell to the Master and Journey to the World) is a 1951 American black-and-white science fiction film from 20th Century Fox, produced by Julian Blaustein and directed by Robert Wise. 0.1.x versions of Archivist will parse and return article content as Archivist.Article structs. The parsing output of the above article example would look like this: %Archivist.Article{ author: &quot;Julian Blaustein&quot;, content: &quot;The Day the Earth Stood Still (a.k.a. Farewell to the Master and Journey to the\\nWorld) is a 1951 American black-and-white science fiction film from 20th Century\\nFox, produced by Julian Blaustein and directed by Robert Wise.\\n&quot;, created_at: #DateTime&lt;2019-01-20 22:24:00Z&gt;, email: &quot;julian@blaustein.com&quot;, published_at: #DateTime&lt;2019-04-02 04:30:00Z&gt;, slug: &quot;the-day-the-earth-stood-still&quot;, summary: &quot;A sci-fi classic about a flying saucer landing in Washington, D.C.&quot;, tags: [:sci_fi, :horror, :thrillers, :aliens], title: &quot;The Day the Earth Stood Still&quot;, topics: [&quot;Films&quot;, &quot;Sci-Fi&quot;, &quot;Classic&quot;] }"},{"ref":"readme.html#development-notes","title":"Archivist - Development Notes","type":"extras","doc":"A quick review of the Archivist.Archive implementation would reveal additional options that aren&#39;t otherwise mentioned in this README: defmodule MyApp.Archive use Archivist.Archive content_parser: Earmark, article_parser: Arcdown, application: nil end These options are currently placeholders for future functionality but do not serve any purpose to the user for the time being. Some notes on forthcoming features: While Earmark is included with Archivist, functionality for parsing content as Earmark has not yet been added. Future versions (like 0.3.x) will add something like a parsed_content attribute to the parsed articles flag, which will contain content parsed as Earmark. Setting this value to nil will cause the article parser not to parse the content at compile-time. The intent of the application flag is to be able to define an OTP app as the target for the archive, allowing for the archived data to be called from a besides the one in which Archivist.Archive is used. Please note that this functionality is currently not working and should not be used until further notice in this README. Also note that that swapping out the content and article parsers with different modules currently is not supported. ContentParser and ArticleParser behaviors will be implemented in future versions (likely 0.3.x) and will support implementing custom parsers for these elements. Please find additional information about known issues and planned features for Archivist in the issues tracker."},{"ref":"readme.html#todo","title":"Archivist - Todo","type":"extras","doc":"Issues and Todo enhancements are managed at the official Archivist issues tracker on GitHub."},{"ref":"readme.html#availability","title":"Archivist - Availability","type":"extras","doc":"Source code is available at the official Archivist repository on the FunctionHaus GitHub Organization"},{"ref":"readme.html#license","title":"Archivist - License","type":"extras","doc":"Archivist source code is released under Apache 2 License. Check LICENSE file for more information. &copy; 2017 FunctionHaus, LLC"}]